package cn.gygxzc.envir.core.entity;

import cn.gygxzc.envir.core.ex.ParamMissException;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import org.springframework.util.StringUtils;

import javax.activation.DataSource;
import java.io.Serializable;
import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * @author tuonina
 * @createTime 2019/2/25
 * 自定义的邮件实体类
 */
public class MailEntity implements Serializable {

    public final static long serialVersionUID = 2L;
    public final static String SEP = ",";

    private Long id;
    private String to;
    private String subject;
    private String content;
    private String attachments;
    private MailType type = MailType.SIMP;
    private String rscPath;
    private String filePath;
    private String rscId;
    /**
     * 抄送收件人信息
     * 收件人能看见抄送人信息
     */
    private List<String> cc;
    /**
     * 匿名抄送收件人，
     * 匿名：表示收件人看不见抄送人的邮箱地址
     */
    private List<String> bcc;
    private DataSource dataSource;
    private String fileName;
    private Date createTime;

    public MailEntity() {
        this.cc = Collections.emptyList();
        this.bcc = Collections.emptyList();
        this.createTime = new Date();
        id = IdWorker.getId();
    }

    public void setDataSource(DataSource dataSource) {
        this.dataSource = dataSource;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public DataSource getDataSource() {
        return dataSource;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFileName() {
        return fileName;
    }

    public String getTo() {
        return to;
    }

    public void setTo(String to) {
        this.to = to;
    }

    public String getSubject() {
        return subject;
    }

    public void setSubject(String subject) {
        this.subject = subject;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getAttachments() {
        return attachments;
    }

    public void setAttachments(String attachments) {
        this.attachments = attachments;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }

    public String getFilePath() {
        return filePath;
    }

    public MailType getType() {
        return type;
    }

    public void setType(MailType type) {
        this.type = type;
    }

    public String getRscPath() {
        return rscPath;
    }

    public void setRscPath(String rscPath) {
        this.rscPath = rscPath;
    }

    public String getRscId() {
        return rscId;
    }

    public void setRscId(String rscId) {
        this.rscId = rscId;
    }

    public List<String> getCc() {
        return cc;
    }

    public void setCc(List<String> cc) {
        this.cc = cc;
    }


    public List<String> getBcc() {
        return bcc;
    }

    public void setBcc(List<String> bcc) {
        this.bcc = bcc;
    }

    public void checkParams() throws RuntimeException {
        if (!StringUtils.hasLength(to)) {
            throw new ParamMissException("无发送对象！");
        }
        if (!StringUtils.hasLength(subject)) {
            throw new ParamMissException("无邮件主题！");
        }
        if (!StringUtils.hasLength(content)) {
            throw new ParamMissException("无邮件内容！");
        }
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    /**
     * SIMP  纯文档，也不存在附件的
     */
    public enum MailType {
        SIMP, HTML, ATTACHMENTS, TEMPLATE
    }

    @Override
    public String toString() {
        return String.format("to:%s  ", to) +
                String.format("subject:%s  ", subject) +
                String.format("content:%s  ", content);
    }
}
